@@ -19,7 +19,7 @@ from docutils.parsers.rst import directives, Directive
 
 from sphinx import addnodes
 from sphinx.roles import XRefRole
-from sphinx.locale import l_, _
+from sphinx.locale import _
 from sphinx.domains import Domain, ObjType, Index
 from sphinx.directives import ObjectDescription
 from sphinx.util.nodes import make_refnode
@@ -94,21 +94,21 @@ class MatObject(ObjectDescription):
     }
 
     doc_field_types = [
-        TypedField('parameter', label=l_('Parameters'),
+        TypedField('parameter', label=_('Parameters'),
                    names=('param', 'parameter', 'arg', 'argument',
                           'keyword', 'kwarg', 'kwparam'),
                    typerolename='obj', typenames=('paramtype', 'type'),
                    can_collapse=True),
-        TypedField('variable', label=l_('Variables'), rolename='obj',
+        TypedField('variable', label=_('Variables'), rolename='obj',
                    names=('var', 'ivar', 'cvar'),
                    typerolename='obj', typenames=('vartype',),
                    can_collapse=True),
-        GroupedField('exceptions', label=l_('Raises'), rolename='exc',
+        GroupedField('exceptions', label=_('Raises'), rolename='exc',
                      names=('raises', 'raise', 'exception', 'except'),
                      can_collapse=True),
-        Field('returnvalue', label=l_('Returns'), has_arg=False,
+        Field('returnvalue', label=_('Returns'), has_arg=False,
               names=('returns', 'return')),
-        Field('returntype', label=l_('Return type'), has_arg=False,
+        Field('returntype', label=_('Return type'), has_arg=False,
               names=('rtype',)),
     ]
 
@@ -490,8 +490,8 @@ class MATLABModuleIndex(Index):
     """
 
     name = 'modindex'
-    localname = l_('MATLAB Module Index')
-    shortname = l_('modules')
+    localname = _('MATLAB Module Index')
+    shortname = _('modules')
 
     def generate(self, docnames=None):
         content = {}
@@ -559,15 +559,16 @@ class MATLABDomain(Domain):
     name = 'mat'
     label = 'MATLAB'
     object_types = {
-        'function':     ObjType(l_('function'),      'func', 'obj'),
-        'data':         ObjType(l_('data'),          'data', 'obj'),
-        'class':        ObjType(l_('class'),         'class', 'obj'),
-        'exception':    ObjType(l_('exception'),     'exc', 'obj'),
-        'method':       ObjType(l_('method'),        'meth', 'obj'),
-        'classmethod':  ObjType(l_('class method'),  'meth', 'obj'),
-        'staticmethod': ObjType(l_('static method'), 'meth', 'obj'),
-        'attribute':    ObjType(l_('attribute'),     'attr', 'obj'),
-        'module':       ObjType(l_('module'),        'mod', 'obj'),
+        'function':     ObjType(_('function'),      'func', 'obj'),
+        'data':         ObjType(_('data'),          'data', 'obj'),
+        'class':        ObjType(_('class'),         'class', 'obj'),
+        'exception':    ObjType(_('exception'),     'exc', 'obj'),
+        'method':       ObjType(_('method'),        'meth', 'obj'),
+        'classmethod':  ObjType(_('class method'),  'meth', 'obj'),
+        'staticmethod': ObjType(_('static method'), 'meth', 'obj'),
+        'attribute':    ObjType(_('attribute'),     'attr', 'obj'),
+        'module':       ObjType(_('module'),        'mod', 'obj'),
+        'script':       ObjType(_('script'),        'scpt', 'obj'),
     }
 
     directives = {
@@ -583,6 +584,7 @@ class MATLABDomain(Domain):
         'currentmodule':   MatCurrentModule,
         'decorator':       MatDecoratorFunction,
         'decoratormethod': MatDecoratorMethod,
+        'script':            MatModulelevel,
     }
     roles = {
         'data':  MatXRefRole(),
@@ -594,6 +596,7 @@ class MATLABDomain(Domain):
         'meth':  MatXRefRole(fix_parens=True),
         'mod':   MatXRefRole(),
         'obj':   MatXRefRole(),
+        'scpt':   MatXRefRole(),
     }
     initial_data = {
         'objects': {},  # fullname -> docname, objtype
@@ -724,3 +727,4 @@ def setup(app):
     app.add_autodocumenter(doc.MatMethodDocumenter)
     app.add_autodocumenter(doc.MatAttributeDocumenter)
     app.add_autodocumenter(doc.MatInstanceAttributeDocumenter)
+    app.add_autodocumenter(doc.MatScriptDocumenter)
